@@ -4,19 +4,11 @@ dicom2nifti
 
 @author: abrys
 """
-from __future__ import print_function
-
-import nibabel
-
 import dicom2nifti.compressed_dicom as compressed_dicom
-import dicom2nifti.patch_pydicom_encodings
-
-dicom2nifti.patch_pydicom_encodings.apply()
 
 import os
 import struct
 
-import pydicom
 from pydicom.tag import Tag
 
 import logging
@@ -35,7 +27,7 @@ def read_dicom_directory(dicom_directory, stop_before_pixels=False):
     Read all dicom files in a given directory (stop before pixels)
 
     :type stop_before_pixels: bool
-    :type dicom_directory: six.string_types
+    :type dicom_directory: str
     :param stop_before_pixels: Should we stop reading before the pixeldata (handy if we only want header info)
     :param dicom_directory: Directory with dicom data
     :return: List of dicom objects
@@ -585,13 +577,12 @@ def is_orthogonal(dicoms, log_details=False):
     return True
 
 
-def is_orthogonal_nifti(nifti_file):
+def is_orthogonal_nifti(nifti_image):
     """
     Validate that volume is orthonormal
 
     :param dicoms: check that we have a volume without skewing
     """
-    nifti_image = nibabel.load(nifti_file)
     affine = nifti_image.affine
 
     transformed_x = numpy.transpose(numpy.dot(affine, [[1], [0], [0], [0]]))[0][:3]
@@ -731,3 +722,9 @@ def set_tr_te(nifti_image, repetition_time, echo_time):
     nifti_image.header.structarr['db_name'] = '?TR:%.3f TE:%d' % (repetition_time, echo_time)
 
     return nifti_image
+
+def get_nifti_data(nifti_image):
+    """
+    Function that replicates the deprecated nifti.get_data behavior
+    """
+    return numpy.asanyarray(nifti_image.dataobj)
\ No newline at end of file
