@@ -4,22 +4,14 @@ dicom2nifti
 
 @author: abrys
 """
-from __future__ import print_function
-
 import logging
 
 import dicom2nifti.compressed_dicom as compressed_dicom
-import dicom2nifti.patch_pydicom_encodings
 from dicom2nifti import convert_hitachi
 
-dicom2nifti.patch_pydicom_encodings.apply()
-
 import os
 import tempfile
 import shutil
-import sys
-
-from six import reraise
 
 from pydicom.tag import Tag
 
@@ -86,10 +78,7 @@ def dicom_series_to_nifti(original_dicom_directory, output_file=None, reorient_n
         return dicom_array_to_nifti(dicom_input, output_file, reorient_nifti)
 
     except AttributeError as exception:
-        reraise(
-            tp=ConversionError,
-            value=ConversionError(str(exception)),
-            tb=sys.exc_info()[2])
+        raise exception
 
     finally:
         # remove the copied data
@@ -124,6 +113,7 @@ def dicom_array_to_nifti(dicom_list, output_file, reorient_nifti=True):
         raise ConversionValidationError('NON_IMAGING_DICOM_FILES')
 
     vendor = _get_vendor(dicom_list)
+
     if vendor == Vendor.GENERIC:
         results = convert_generic.dicom_to_nifti(dicom_list, output_file)
     elif vendor == Vendor.SIEMENS:
@@ -139,12 +129,12 @@ def dicom_array_to_nifti(dicom_list, output_file, reorient_nifti=True):
 
     # do image reorientation if needed
     if reorient_nifti or settings.resample:
-        image_reorientation.reorient_image(results['NII_FILE'], results['NII_FILE'])
+        image_reorientation.reorient_image(results['NII'], results['NII_FILE'])
 
     # resampling needs to be after reorientation
     if settings.resample:
-        if not common.is_orthogonal_nifti(results['NII_FILE']):
-            resample.resample_single_nifti(results['NII_FILE'])
+        if not common.is_orthogonal_nifti(results['NII']):
+            resample.resample_single_nifti(results['NII'], results['NII_FILE'])
 
     return results
 
