@@ -4,24 +4,16 @@ dicom2nifti
 
 @author: abrys
 """
-
-from __future__ import print_function
-import dicom2nifti.patch_pydicom_encodings
-
-dicom2nifti.patch_pydicom_encodings.apply()
-
 import logging
 import nibabel
 import numpy
 
 from pydicom.tag import Tag
 
-import six
-
 import dicom2nifti.common as common
 import dicom2nifti.settings as settings
 import dicom2nifti.resample as resample
-from dicom2nifti.exceptions import ConversionError
+from dicom2nifti.exceptions import ConversionError, ConversionValidationError
 
 logger = logging.getLogger(__name__)
 
@@ -39,13 +31,18 @@ def dicom_to_nifti(dicom_input, output_file):
         raise ConversionError('NO_DICOM_FILES_FOUND')
 
     # remove duplicate slices based on position and data
-    dicom_input = _remove_duplicate_slices(dicom_input)
+    dicom_input = remove_duplicate_slices(dicom_input)
 
     # remove localizers based on image type
-    dicom_input = _remove_localizers_by_imagetype(dicom_input)
+    dicom_input = remove_localizers_by_imagetype(dicom_input)
+    # if no dicoms remain we should raise exception
+    if len(dicom_input) < 1:
+        raise ConversionValidationError('TOO_FEW_SLICES/LOCALIZER')
+
     if settings.validate_slicecount:
+        common.validate_slicecount(dicom_input)
         # remove_localizers based on image orientation (only valid if slicecount is validated)
-        dicom_input = _remove_localizers_by_orientation(dicom_input)
+        dicom_input = remove_localizers_by_orientation(dicom_input)
 
         # validate all the dicom files for correct orientations
         common.validate_slicecount(dicom_input)
@@ -78,10 +75,10 @@ def dicom_to_nifti(dicom_input, output_file):
         affine, max_slice_increment = common.create_affine(dicom_input)
 
         # Convert to nifti
-        nii_image = nibabel.Nifti1Image(data, affine)
+        nii_image = nibabel.Nifti1Image(data.squeeze(), affine)
 
     # Set TR and TE if available
-    if Tag(0x0018, 0x0081) in dicom_input[0] and Tag(0x0018, 0x0081) in dicom_input[0]:
+    if Tag(0x0018, 0x0080) in dicom_input[0] and Tag(0x0018, 0x0081) in dicom_input[0]:
         common.set_tr_te(nii_image, float(dicom_input[0].RepetitionTime), float(dicom_input[0].EchoTime))
 
     # Save to disk
@@ -94,7 +91,7 @@ def dicom_to_nifti(dicom_input, output_file):
             'MAX_SLICE_INCREMENT': max_slice_increment}
 
 
-def _remove_duplicate_slices(dicoms):
+def remove_duplicate_slices(dicoms):
     """
     Search dicoms for localizers and delete them
     """
@@ -102,6 +99,10 @@ def _remove_duplicate_slices(dicoms):
 
     dicoms_dict = {}
     filtered_dicoms = []
+    # in case of multiframe this check cannot be done
+    if 'ImageOrientationPatient' not in dicoms[0]:
+        return dicoms
+
     for dicom_ in dicoms:
         if tuple(dicom_.ImagePositionPatient) not in dicoms_dict:
             dicoms_dict[tuple(dicom_.ImagePositionPatient)] = dicom_
@@ -115,7 +116,7 @@ def _remove_duplicate_slices(dicoms):
     return filtered_dicoms
 
 
-def _remove_localizers_by_imagetype(dicoms):
+def remove_localizers_by_imagetype(dicoms):
     """
     Search dicoms for localizers and delete them
     """
@@ -131,7 +132,7 @@ def _remove_localizers_by_imagetype(dicoms):
     return filtered_dicoms
 
 
-def _remove_localizers_by_orientation(dicoms):
+def remove_localizers_by_orientation(dicoms):
     """
     Removing localizers based on the orientation.
     This is needed as in some cases with ct data there are some localizer/projection type images that cannot
@@ -140,6 +141,11 @@ def _remove_localizers_by_orientation(dicoms):
     """
     orientations = []
     sorted_dicoms = {}
+
+    # in case of multiframe this check cannot be done
+    if 'ImageOrientationPatient' not in dicoms[0]:
+        return dicoms
+
     # Loop overall files and build dict
     for dicom_header in dicoms:
         # Create affine matrix (http://nipy.sourceforge.net/nibabel/dicom/dicom_orientation.html#dicom-slice-affine)
@@ -168,7 +174,7 @@ def _remove_localizers_by_orientation(dicoms):
                 filtered_dicoms.extend(sorted_dicoms[orientation])
         return filtered_dicoms
     else:
-        return six.next(six.itervalues(sorted_dicoms))
+        return next(iter(sorted_dicoms.values()))
 
 
 def _convert_slice_incement_inconsistencies(dicom_input):
@@ -204,7 +210,7 @@ def _convert_slice_incement_inconsistencies(dicom_input):
     for dicom_slices in slice_incement_groups:
         data = common.get_volume_pixeldata(dicom_slices)
         affine, _ = common.create_affine(dicom_slices)
-        current_volume = nibabel.Nifti1Image(data, affine)
+        current_volume = nibabel.Nifti1Image(data.squeeze(), affine)
         slice_increment = numpy.linalg.norm(current_volume.header.get_zooms())
         voxel_sizes['%.5f' % slice_increment] = current_volume.header.get_zooms()
         slice_increments.extend([slice_increment] * (len(dicom_slices)-1))
