@@ -6,13 +6,10 @@ Created on Thu Aug  1 16:10:56 2013
 """
 # To ignore numpy errors:
 #     pylint: disable=E1101
-
-from __future__ import print_function
-
 import nibabel
 import numpy
 
-from dicom2nifti.image_volume import load, SliceType
+from dicom2nifti.image_volume import load, SliceType, ImageVolume
 
 
 def reorient_image(input_image, output_image):
@@ -28,7 +25,10 @@ def reorient_image(input_image, output_image):
     # Use the imageVolume module to find which coordinate corresponds to each plane
     # and get the image data in RAS orientation
     # print 'Reading nifti'
-    image = load(input_image)
+    if isinstance(input_image, nibabel.Nifti1Image):
+        image = ImageVolume(input_image)
+    else:
+        image = load(input_image)
 
     # 4d have a different conversion to 3d
     # print 'Reorganizing data'
@@ -77,7 +77,7 @@ def reorient_image(input_image, output_image):
     # DONE: Needs to update new_affine, so that there is no translation difference between the original
     # and created image (now there is 1-2 voxels translation)
     # print 'Creating new nifti image'
-    nibabel.nifti1.Nifti1Image(new_image, new_affine).to_filename(output_image)
+    nibabel.nifti1.Nifti1Image(new_image.squeeze(), new_affine).to_filename(output_image)
 
 
 def _reorient_4d(image):
